@@ -93,7 +93,7 @@ class Recipe(zc.recipe.egg.Eggs):
                 destfile = os.path.join(bindir, fn)
                 if os.path.exists(destfile):
                     os.unlink(destfile)
-                os.symlink(fullname, bindir)
+                os.symlink(fullname, destfile)
 
         for path in remove_after_install:
             shutil.rmtree(path)
